#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lrucache
version:              1.2.0.1
visibility:           public
id:                   lrucache-1.2.0.1-EBfvOUy9hfV45PCe0XEQ7e
key:                  lrucache-1.2.0.1-EBfvOUy9hfV45PCe0XEQ7e
license:              BSD-3-Clause
copyright:            Carl Howells, 2010-2015
maintainer:           chowells79@gmail.com
author:               Carl Howells
stability:            Experimental
homepage:             http://github.com/chowells79/lrucache
synopsis:             a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".

    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.

category:             Data
abi:                  3d783e595b4a389294421fa4d66d270e
exposed:              True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal

import-dirs:          /usr/lib/ghc-9.6.6/site-local/lrucache-1.2.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lrucache-1.2.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lrucache
hs-libraries:         HSlrucache-1.2.0.1-EBfvOUy9hfV45PCe0XEQ7e
depends:
    base-4.18.2.1 containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW

haddock-interfaces:   /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html:         /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

